# Nightwatch

The chatting application to end all chatting applications.  
Are you like me, where over the past 5 years you've made several terminal chatting apps? No? Just me?

Regardless,  
Nightwatch is a modern solution to solve my insatiable need for making chatting apps.

---

Jokes aside, Nightwatch is a terminal based, IRC-like, chatting application for Linux/Windows/Mac OS/Mars Rover.  
It's based on a modern architecture (FastAPI, Websockets, and a debloated Python client), and is meant to keep it simple.

---

Project status: **starting development**.  
This README will be filled out as time goes on.
